import { ChainTransaction } from "../../businessObjects/versioned/ChainTransaction.js";
import { EVMTransaction } from "../../businessObjects/versioned/EVMTransaction.js";
import { SolanaTransaction } from "../../businessObjects/versioned/SolanaTransaction.js";
import { SuiTransaction } from "../../businessObjects/versioned/SuiTransaction.js";
import { VersionedObjectMigrator } from "../../businessObjects/versioned/VersionedObject.js";
import { getChainInfoByChainId } from "../../configuration/index.js";
import { EChainTechnology } from "../../enum/index.js";
export class ChainTransactionMigrator extends VersionedObjectMigrator {
    getCurrentVersion() {
        return ChainTransaction.CURRENT_VERSION;
    }
    factory(data) {
        switch (getChainInfoByChainId(data.chain).chainTechnology) {
            case EChainTechnology.Solana: {
                const solanaTransaction = data;
                return new SolanaTransaction(solanaTransaction.chainId, solanaTransaction.hash, solanaTransaction.timestamp, solanaTransaction.slot, solanaTransaction.err, solanaTransaction.memo, solanaTransaction.measurementDate);
            }
            case EChainTechnology.EVM: {
                const evmTransaction = data;
                return new EVMTransaction(evmTransaction.chain, evmTransaction.hash, evmTransaction.timestamp, evmTransaction.blockHeight, evmTransaction.to, evmTransaction.from, evmTransaction.value, evmTransaction.gasPrice, evmTransaction.contractAddress, evmTransaction.input, evmTransaction.methodId, evmTransaction.functionName, evmTransaction.events, evmTransaction.measurementDate);
            }
            case EChainTechnology.Sui: {
                const suiTransaction = data;
                return new SuiTransaction(suiTransaction.chain, suiTransaction.hash, suiTransaction.timestamp, suiTransaction.to, suiTransaction.from, suiTransaction.value, suiTransaction.gasPrice, suiTransaction.contractAddress, suiTransaction.input, suiTransaction.methodId, suiTransaction.functionName, null, // TODO: fix whatever is going on with events
                suiTransaction.measurementDate);
            }
            default:
                throw new Error("chain ID does not match known technology");
        }
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
//# sourceMappingURL=ChainTransactionMigrator.js.map