import { DirectReward } from "../../businessObjects/rewards/DirectReward.js";
import { EarnedReward } from "../../businessObjects/rewards/EarnedReward.js";
import { LazyReward } from "../../businessObjects/rewards/LazyReward.js";
import { Web2Reward } from "../../businessObjects/rewards/Web2Reward.js";
import { VersionedObjectMigrator } from "../../businessObjects/versioned/VersionedObject.js";
import { ERewardType } from "../../enum/ERewardType.js";
export class EarnedRewardMigrator extends VersionedObjectMigrator {
    getCurrentVersion() {
        return EarnedReward.CURRENT_VERSION;
    }
    factory(data) {
        switch (data.type) {
            case ERewardType.Web2: {
                const web2Reward = data;
                return new Web2Reward(web2Reward.queryCID, web2Reward.name, web2Reward.image, web2Reward.description, web2Reward.url, web2Reward.credentialType, web2Reward.credential, web2Reward.instructions);
            }
            case ERewardType.Direct: {
                const directReward = data;
                return new DirectReward(directReward.queryCID, directReward.name, directReward.image, directReward.description, directReward.chainId, directReward.contractAddress, directReward.recipientAddress);
            }
            case ERewardType.Lazy: {
                const lazyReward = data;
                return new LazyReward(lazyReward.queryCID, lazyReward.name, lazyReward.image, lazyReward.description, lazyReward.chainId, lazyReward.contractAddress, lazyReward.recipientAddress, lazyReward.functionName, lazyReward.functionParams);
            }
            default:
                throw new Error(`Factory not implemented for ${data.type}`);
        }
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
//# sourceMappingURL=EarnedRewardMigrator.js.map