import Crypto from "crypto";
import { VersionedObject, VersionedObjectMigrator, } from "../../businessObjects/versioned/VersionedObject.js";
import { SHA256Hash } from "../../primitives/index.js";
export class QuestionnaireData extends VersionedObject {
    constructor(id, questions, title, questionHashes, description, image) {
        super();
        this.id = id;
        this.questions = questions;
        this.title = title;
        this.questionHashes = questionHashes;
        this.description = description;
        this.image = image;
    }
    getVersion() {
        return QuestionnaireData.CURRENT_VERSION;
    }
}
QuestionnaireData.CURRENT_VERSION = 2;
export class QuestionnaireMigrator extends VersionedObjectMigrator {
    getCurrentVersion() {
        return QuestionnaireData.CURRENT_VERSION;
    }
    factory(data) {
        return new QuestionnaireData(data.id, data.questions, data.title, data.questionHashes, data.description, data.image);
    }
    getUpgradeFunctions() {
        return new Map([
            [
                1,
                (data) => {
                    if ("status" in data) {
                        delete data.status;
                    }
                    data.questionHashes = data.questions?.map(({ index, ...question }) => {
                        const questionString = JSON.stringify(question, (key, value) => {
                            if (value instanceof Map) {
                                return {
                                    dataType: "Map",
                                    value: Array.from(value.entries()),
                                };
                            }
                            else if (value instanceof Set) {
                                return {
                                    dataType: "Set",
                                    value: [...value],
                                };
                            }
                            else if (value instanceof BigInt) {
                                return {
                                    dataType: "BigInt",
                                    value: value.toString(),
                                };
                            }
                            else if (typeof value == "bigint") {
                                return {
                                    dataType: "bigint",
                                    value: BigInt(value).toString(),
                                };
                            }
                            else {
                                return value;
                            }
                        });
                        const questionHash = Crypto.createHash("sha256")
                            .update(questionString)
                            .digest("hex");
                        return [index, SHA256Hash(questionHash)];
                    });
                    return data;
                },
            ],
        ]);
    }
}
//# sourceMappingURL=QuestionnaireMigrator.js.map