import { VersionedObject, VersionedObjectMigrator, } from "../../businessObjects/versioned/VersionedObject.js";
import { ESocialType } from "../../enum/index.js";
import { SocialPrimaryKey, } from "../../primitives/index.js";
export class SocialGroupProfile extends VersionedObject {
    constructor(pKey, type, ownerId) {
        super();
        this.pKey = pKey;
        this.type = type;
        this.ownerId = ownerId;
    }
}
SocialGroupProfile.CURRENT_VERSION = 1;
export class InvalidSocialGroupProfile extends SocialGroupProfile {
    constructor(pKey, type, ownerId) {
        super(pKey, type, ownerId);
        this.pKey = pKey;
        this.type = type;
        this.ownerId = ownerId;
    }
    getVersion() {
        return InvalidSocialGroupProfile.CURRENT_VERSION;
    }
}
InvalidSocialGroupProfile.CURRENT_VERSION = 1;
export class SocialGroupProfileMigrator extends VersionedObjectMigrator {
    getCurrentVersion() {
        return SocialGroupProfile.CURRENT_VERSION;
    }
    constructor() {
        super();
        this.discordMigrator = new DiscordGuildProfileMigrator();
    }
    factory(data) {
        switch (data.type) {
            case ESocialType.DISCORD:
                return this.discordMigrator.factory(data);
        }
        const invalidSocialGroupProfile = data;
        return new InvalidSocialGroupProfile(// Cannot return null
        invalidSocialGroupProfile.pKey, invalidSocialGroupProfile.type, invalidSocialGroupProfile.ownerId);
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
export class DiscordGuildProfile extends SocialGroupProfile {
    constructor(id, discordUserProfileId, // this should be translated to ownerId
    name, isOwner, permissions, icon, joinedAt) {
        super(SocialPrimaryKey(`discord-group-${id}`), ESocialType.DISCORD, discordUserProfileId
            ? SocialPrimaryKey(`discord-${discordUserProfileId}`)
            : undefined);
        this.id = id;
        this.discordUserProfileId = discordUserProfileId;
        this.name = name;
        this.isOwner = isOwner;
        this.permissions = permissions;
        this.icon = icon;
        this.joinedAt = joinedAt;
    }
    deriveKey(id) {
        return SocialPrimaryKey(`discord-group-${id}`);
    }
    getVersion() {
        return DiscordGuildProfile.CURRENT_VERSION;
    }
}
DiscordGuildProfile.CURRENT_VERSION = 1;
export class DiscordGuildProfileMigrator {
    factory(data) {
        return new DiscordGuildProfile(data.id, data.discordUserProfileId, data.name, data.isOwner, data.permissions, data.icon, data.joinedAt);
    }
}
//# sourceMappingURL=SocialGroupProfile.js.map