import { OAuth2Tokens } from "../../businessObjects/OAuth2Tokens.js";
import { VersionedObject, VersionedObjectMigrator, } from "../../businessObjects/versioned/VersionedObject.js";
import { ESocialType } from "../../enum/index.js";
import { SocialPrimaryKey, } from "../../primitives/index.js";
export class SocialProfile extends VersionedObject {
    constructor(pKey, type) {
        super();
        this.pKey = pKey;
        this.type = type;
    }
    getVersion() {
        return SocialProfile.CURRENT_VERSION;
    }
}
SocialProfile.CURRENT_VERSION = 1;
export class InvalidSocialProfile extends SocialProfile {
    constructor(pKey, type) {
        super(pKey, type);
        this.pKey = pKey;
        this.type = type;
    }
    getVersion() {
        return InvalidSocialProfile.CURRENT_VERSION;
    }
}
InvalidSocialProfile.CURRENT_VERSION = 1;
export class SocialProfileMigrator extends VersionedObjectMigrator {
    getCurrentVersion() {
        return SocialProfile.CURRENT_VERSION;
    }
    constructor() {
        super();
        this.discordMigrator = new DiscordProfileMigrator();
        this.twitterMigrator = new TwitterProfileMigrator();
    }
    factory(data) {
        switch (data.type) {
            case ESocialType.DISCORD:
                return this.discordMigrator.factory(data);
            case ESocialType.TWITTER:
                return this.twitterMigrator.factory(data);
        }
        return new InvalidSocialProfile(// Cannot return null
        SocialPrimaryKey(data["pKey"]), ESocialType[data["type"]]);
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
export class DiscordProfile extends SocialProfile {
    constructor(id, username, displayName, discriminator, avatar, flags, oauth2Tokens) {
        super(SocialPrimaryKey(`discord-${id}`), ESocialType.DISCORD);
        this.id = id;
        this.username = username;
        this.displayName = displayName;
        this.discriminator = discriminator;
        this.avatar = avatar;
        this.flags = flags;
        this.oauth2Tokens = oauth2Tokens;
    }
    deriveKey(id) {
        return SocialPrimaryKey(`discord-${id}`);
    }
}
export class DiscordProfileMigrator {
    factory(data) {
        return new DiscordProfile(data.id, data.username, data.displayName, data.discriminator, data.avatar, data.flags, new OAuth2Tokens(data.oauth2Tokens.accessToken, data.oauth2Tokens.refreshToken, data.oauth2Tokens.expiry));
    }
}
export class TwitterUserObject {
    constructor(id, username, name) {
        this.id = id;
        this.username = username;
        this.name = name;
    }
}
export class TwitterFollowData {
    constructor(following, followers) {
        this.following = following;
        this.followers = followers;
    }
}
export class TwitterProfile extends SocialProfile {
    constructor(userObject, oAuth1a, followData) {
        super(SocialPrimaryKey(`twitter-${userObject.id}`), ESocialType.TWITTER);
        this.userObject = userObject;
        this.oAuth1a = oAuth1a;
        this.followData = followData;
    }
    deriveKey(id) {
        return SocialPrimaryKey(`twitter-${id}`);
    }
}
export class TwitterProfileMigrator {
    factory(data) {
        return new TwitterProfile(new TwitterUserObject(data.userObject.id, data.userObject.username, data.userObject.name), data.oAuth1a, data.followData);
    }
}
//# sourceMappingURL=SocialProfile.js.map